import { element, by, ElementFinder } from 'protractor';

export class UserWatchListComponentsPage {
  createButton = element(by.id('jh-create-entity'));
  deleteButtons = element.all(by.css('jhi-user-watch-list div table .btn-danger'));
  title = element.all(by.css('jhi-user-watch-list div h2#page-heading span')).first();
  noResult = element(by.id('no-result'));
  entities = element(by.id('entities'));

  async clickOnCreateButton(): Promise<void> {
    await this.createButton.click();
  }

  async clickOnLastDeleteButton(): Promise<void> {
    await this.deleteButtons.last().click();
  }

  async countDeleteButtons(): Promise<number> {
    return this.deleteButtons.count();
  }

  async getTitle(): Promise<string> {
    return this.title.getAttribute('jhiTranslate');
  }
}

export class UserWatchListUpdatePage {
  pageTitle = element(by.id('jhi-user-watch-list-heading'));
  saveButton = element(by.id('save-entity'));
  cancelButton = element(by.id('cancel-save'));

  nameInput = element(by.id('field_name'));
  checkFrequencySelect = element(by.id('field_checkFrequency'));

  userIdSelect = element(by.id('field_userId'));

  async getPageTitle(): Promise<string> {
    return this.pageTitle.getAttribute('jhiTranslate');
  }

  async setNameInput(name: string): Promise<void> {
    await this.nameInput.sendKeys(name);
  }

  async getNameInput(): Promise<string> {
    return await this.nameInput.getAttribute('value');
  }

  async setCheckFrequencySelect(checkFrequency: string): Promise<void> {
    await this.checkFrequencySelect.sendKeys(checkFrequency);
  }

  async getCheckFrequencySelect(): Promise<string> {
    return await this.checkFrequencySelect.element(by.css('option:checked')).getText();
  }

  async checkFrequencySelectLastOption(): Promise<void> {
    await this.checkFrequencySelect.all(by.tagName('option')).last().click();
  }

  async userIdSelectLastOption(): Promise<void> {
    await this.userIdSelect.all(by.tagName('option')).last().click();
  }

  async userIdSelectOption(option: string): Promise<void> {
    await this.userIdSelect.sendKeys(option);
  }

  getUserIdSelect(): ElementFinder {
    return this.userIdSelect;
  }

  async getUserIdSelectedOption(): Promise<string> {
    return await this.userIdSelect.element(by.css('option:checked')).getText();
  }

  async save(): Promise<void> {
    await this.saveButton.click();
  }

  async cancel(): Promise<void> {
    await this.cancelButton.click();
  }

  getSaveButton(): ElementFinder {
    return this.saveButton;
  }
}

export class UserWatchListDeleteDialog {
  private dialogTitle = element(by.id('jhi-delete-userWatchList-heading'));
  private confirmButton = element(by.id('jhi-confirm-delete-userWatchList'));

  async getDialogTitle(): Promise<string> {
    return this.dialogTitle.getAttribute('jhiTranslate');
  }

  async clickOnConfirmButton(): Promise<void> {
    await this.confirmButton.click();
  }
}
